% KalmanFilterParameters.m
%
% Load the parameters of the Kalman filter design of Sec. IV-B.
%
% The script loads the matrices of the state space model of the Balancing 
% Cube and defines the parameters for the Kalman filter.
%
%
% --
% Supplementary material to
%
% S. Trimpe, R. D'Andrea, "Reduced Communication State Estimation for 
% Control of an Unstable Networked Control System", 50th IEEE Conference 
% on Decision and Control and European Control Conference, 2011.
%
% Copyright:
% Sebastian Trimpe
% ETH Zurich
% Institute for Dynamic Systems and Control (IDSC)
% strimpe(at)ethz.ch
% September 2011
%


%% Load model data.
% Load Balancing Cube model data (A,C).
load('CubeModel.mat');

% number of states
n = size(A,1);



%% Kalman filter parameters.
% Process and measurement noise variances (used as tuning parameters).
Q = diag([1, 1, 1, 1, 1, 1, 0.01, 1]); 
R = diag([0.1 1 0.1 1 0.1 1 0.1 1 0.1 1 0.1 1]);

% Communication parameters \delta_i
delta = 40.2*[1 0 1 0 1 0 1 0 1 0 1 0] + 2*[0 1 0 1 0 1 0 1 0 1 0 1];



%% Compute the solution to the steady-state Kalman filter
% Solve the discrete-time algebraic Riccati equation (DARE).
[P_bar,temp1,temp2] = dare(A',C',Q,R);
